@@ -4,7 +4,7 @@
  * various directory search drivers.  It includes functions for searching,
  * adding, removing, and modifying directory entries.
  *
- * $Horde: turba/lib/Driver.php,v 1.57.2.81 2008/09/22 12:17:13 jan Exp $
+ * $Horde: turba/lib/Driver.php,v 1.57.2.83 2008/10/28 23:40:38 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@csh.rit.edu>
@@ -172,7 +172,8 @@ class Turba_Driver {
     function toDriverKeys($hash)
     {
         /* Handle category. */
-        if (!empty($hash['category'])) {
+        if (!empty($hash['category']) &&
+            $GLOBALS['attributes']['category']['type'] == 'category') {
             if (!empty($hash['category']['new'])) {
                 require_once 'Horde/Prefs/CategoryManager.php';
                 $cManager = new Prefs_CategoryManager();
@@ -1803,7 +1804,8 @@ class Turba_Driver {
                     break;
                 }
                 if (!isset($item['params']['ENCODING']) ||
-                    String::lower($item['params']['ENCODING']) != 'b') {
+                    (String::lower($item['params']['ENCODING']) != 'b' &&
+                     String::upper($item['params']['ENCODING']) != 'BASE64')) {
                     // Invalid property.
                     break;
                 }
