@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Turba.php,v 1.59.4.42 2008/08/25 17:09:48 jan Exp $
+ * $Horde: turba/lib/Turba.php,v 1.59.4.43 2008/10/07 12:56:17 jan Exp $
  *
  * @package Turba
  */
@@ -575,12 +575,15 @@ class Turba {
          * name. */
         $share_id = $share->getName();
 
-        /* Add the new addressbook to the user's list of visible
-         * address books. */
-        $prefs = explode("\n", $GLOBALS['prefs']->getValue('addressbooks'));
-        if (array_search($share_id, $prefs) === false) {
-            $prefs[] = $share_id;
-            $GLOBALS['prefs']->setValue('addressbooks', implode("\n", $prefs));
+        /* Add the new addressbook to the user's list of visible address
+         * books. */
+        $prefs = $GLOBALS['prefs']->getValue('addressbooks');
+        if ($prefs) {
+            $prefs = explode("\n", $prefs);
+            if (array_search($share_id, $prefs) === false) {
+                $prefs[] = $share_id;
+                $GLOBALS['prefs']->setValue('addressbooks', implode("\n", $prefs));
+            }
         }
 
         return $share;
